@@ -2,8 +2,6 @@ from .util import *
 
 
 class Command:
-    command_g_counter = 0
-    command_G_counter = 0
     resolution_mode = 0
 
     def __init__(self, type: PSDTypes):
@@ -27,10 +25,6 @@ class Command:
             cmd += str(value)
         return cmd
 
-    def resetInternalParams(self):
-        self.command_g_counter = 0
-        self.command_G_counter = 0
-
     """
     R - Execute Command Buffer
     X - Execute Command Buffer from Beginning
@@ -115,18 +109,11 @@ class Command:
 
     def definePositionInCommandString(self):
         cmd: str = 'g'
-        self.command_g_counter += 1
-        print("actual value of g command: " + str(self.command_g_counter))
-        if self.command_g_counter > 10:
-            print("Using g command exceed maximum number of usage!")
-            cmd = 'cmdError'
-            self.command_g_counter = 0
         return cmd
 
     # Gx - Repeat Commands
     def repeatCommands(self, value=0):
         cmd: str = 'G'
-        self.command_G_counter += 1
         if value == 0:
             print("default value for Repeat Commands")
         elif 1 <= value <= 65535:
@@ -135,12 +122,6 @@ class Command:
             cmd = 'cmdError'
             print("Wrong parameter value for Repeat Commands command!")
 
-        print("actual value of G command: " + str(self.command_G_counter))
-        if self.command_G_counter > 11:
-            print("Using g command exceed maximum number of usage!")
-            cmd = 'cmdError'
-            self.command_G_counter = 0
-
         return cmd
 
     # Mx - Delay - performs a delay of x milliseconds.where 5 ≤ x ≤ 30,000 milliseconds.
