@@ -60,7 +60,7 @@ class CommandPSD6SmoothFlow(Command):
         Motor Commands
     """
 
-    def mSetStartVelocity(self, value: int):
+    def setStartVelocity(self, value: int):
         cmd: str = 'v'
         if 50 <= value <= 800:
             cmd += str(value)
@@ -69,7 +69,7 @@ class CommandPSD6SmoothFlow(Command):
             print("Wrong parameter value for set start velocity command!")
         return cmd
 
-    def mSetMaximumVelocity(self, value: int):
+    def setMaximumVelocity(self, value: int):
         cmd: str = 'V'
         if 2 <= value <= 3400:
             cmd += str(value)
@@ -78,7 +78,7 @@ class CommandPSD6SmoothFlow(Command):
             print("Wrong parameter value for set maximum velocity command!")
         return cmd
 
-    def mStopVelocity(self, value: int):
+    def stopVelocity(self, value: int):
         cmd: str = 'c'
         if 50 <= value <= 1700:
             cmd += str(value)
@@ -87,7 +87,7 @@ class CommandPSD6SmoothFlow(Command):
             print("Wrong parameter value for stop velocity command!")
         return cmd
 
-    def mSetMaximumMicroStepVelocity(self, value):
+    def setMaximumMicroStepVelocity(self, value):
         cmd: str = 'u'
         if 400 <= value <= 816000:
             cmd += str(value)
@@ -97,5 +97,5 @@ class CommandPSD6SmoothFlow(Command):
         return cmd
 
     # test with a ps6 sf pump
-    def aStopCommandBuffer(self):
+    def stopCommandBuffer(self):
         return 't'
\ No newline at end of file
