@@ -101,8 +101,6 @@ class PSD:
 
         countg = command.count("g")
         countG = command.count("G")
-        print("g in command appears " + str(countg) + " times")
-        print("G in command appears " + str(countG) + " times")
 
         if "cmdError" not in command:
             commandType = self.getTypeOfCommand(command)
